TilingMethod
============

.. currentmodule:: toasty

.. autoclass:: TilingMethod
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TilingMethod.AUTO_DETECT
      ~TilingMethod.HIPS
      ~TilingMethod.TAN
      ~TilingMethod.TOAST
      ~TilingMethod.UNTILED

   .. rubric:: Attributes Documentation

   .. autoattribute:: AUTO_DETECT
   .. autoattribute:: HIPS
   .. autoattribute:: TAN
   .. autoattribute:: TOAST
   .. autoattribute:: UNTILED
